@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2100';
+our $VERSION = '0.2101';
 
 use MIDI::Util qw(set_time_signature);
 use Music::Duration;
@@ -414,7 +414,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2100
+version 0.2101
 
 =head1 SYNOPSIS
 
@@ -451,17 +451,6 @@ version 0.2100
  $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
     for 1 .. $d->beats * $d->bars;
 
- $d->combinatorial( $d->snare, {
-    repeat   => 2,
-    patterns => [qw(0101 1001)],
- });
-
- # Play parts simultaneously
- $d->sync( \&snare, \&kick, \&hhat );
- sub snare { $d->combinatorial( $d->snare, { count => 1 } ) }
- sub kick { $d->combinatorial( $d->kick, { negate => 1 } ) }
- sub hhat { $d->steady( $d->closed_hh ) }
-
  $d->write;
 
 =head1 DESCRIPTION
